package com.fs.live.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fs.common.utils.DateUtils;
import com.fs.live.domain.LiveAnchor;
import com.fs.live.mapper.LiveAnchorMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.live.mapper.LiveMsgMapper;
import com.fs.live.domain.LiveMsg;
import com.fs.live.service.ILiveMsgService;

/**
 * 直播讨论Service业务层处理
 * 
 * @author fs
 * @date 2025-01-17
 */
@Service
public class LiveMsgServiceImpl extends ServiceImpl<LiveMsgMapper, LiveMsg> implements ILiveMsgService
{
    @Autowired
    private LiveMsgMapper liveMsgMapper;

    /**
     * 查询直播讨论
     * 
     * @param msgId 直播讨论主键
     * @return 直播讨论
     */
    @Override
    public LiveMsg selectLiveMsgByMsgId(Long msgId)
    {
        return liveMsgMapper.selectLiveMsgByMsgId(msgId);
    }

    /**
     * 查询直播讨论列表
     * 
     * @param liveMsg 直播讨论
     * @return 直播讨论
     */
    @Override
    public List<LiveMsg> selectLiveMsgList(LiveMsg liveMsg)
    {
        return liveMsgMapper.selectLiveMsgList(liveMsg);
    }

    /**
     * 新增直播讨论
     * 
     * @param liveMsg 直播讨论
     * @return 结果
     */
    @Override
    public int insertLiveMsg(LiveMsg liveMsg)
    {
        liveMsg.setCreateTime(DateUtils.getNowDate());
        return liveMsgMapper.insertLiveMsg(liveMsg);
    }

    /**
     * 修改直播讨论
     * 
     * @param liveMsg 直播讨论
     * @return 结果
     */
    @Override
    public int updateLiveMsg(LiveMsg liveMsg)
    {
        liveMsg.setUpdateTime(DateUtils.getNowDate());
        return liveMsgMapper.updateLiveMsg(liveMsg);
    }

    /**
     * 批量删除直播讨论
     * 
     * @param msgIds 需要删除的直播讨论主键
     * @return 结果
     */
    @Override
    public int deleteLiveMsgByMsgIds(Long[] msgIds)
    {
        return liveMsgMapper.deleteLiveMsgByMsgIds(msgIds);
    }

    /**
     * 删除直播讨论信息
     * 
     * @param msgId 直播讨论主键
     * @return 结果
     */
    @Override
    public int deleteLiveMsgByMsgId(Long msgId)
    {
        return liveMsgMapper.deleteLiveMsgByMsgId(msgId);
    }
}
